#![cfg_attr(not(debug_assertions), windows_subsystem = "windows")]

mod app;
mod utils;

use std::fs;

use ai_core::config::Config;
use once_cell::sync::Lazy;

use crate::app::App;

pub static CONFIG: Lazy<Config> = Lazy::new(|| {
    let config = fs::read_to_string("./config.ron").expect("Failed to read config.ron");

    ron::from_str(&config).expect("Failed to parse config")
});

#[tokio::main]
async fn main() {
    // Forces once_cell to init the config
    Lazy::force(&CONFIG);

    let options = eframe::NativeOptions {
        ..Default::default()
    };

    eframe::run_native("AI Gui", options, Box::new(|_| Box::new(App::default()))).unwrap();
}
